unit MainDemoForm;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  RBTreeView, StdCtrls, ComCtrls, RXCtrls, ExtCtrls, ImgList,
  RxCombos;

type
  TMainDemo = class(TForm)
    TreeView: TRBTreeView;
    TreeFontDialog: TFontDialog;
    TreeImageList: TImageList;
    PropertiesPanel: TPanel;
    CustomDrawingCheckBox: TCheckBox;
    ShowButtonsCheckBox: TCheckBox;
    ShowLinesCheckBox: TCheckBox;
    ShowRootCheckBox: TCheckBox;
    NodeStyleRadioGroup: TRadioGroup;
    ImageSideRadioGroup: TRadioGroup;
    LineStyleRadioGroup: TRadioGroup;
    Label2: TLabel;
    Label3: TLabel;
    Label4: TLabel;
    Label5: TLabel;
    Label6: TLabel;
    Label7: TLabel;
    Label8: TLabel;
    Label9: TLabel;
    Label10: TLabel;
    NodeWidthTrackBar: TTrackBar;
    NodeHeightTrackBar: TTrackBar;
    VertSpacingTrackBar: TTrackBar;
    HorzSpacingTrackBar: TTrackBar;
    ButtonSizeTrackBar: TTrackBar;
    NodeColorComboBox: TColorComboBox;
    NodePenColorComboBox: TColorComboBox;
    TreeColorComboBox: TColorComboBox;
    LineColorComboBox: TColorComboBox;
    SetTreeFontButton: TButton;
    Label11: TLabel;
    WebPanel: TPanel;
    RichEdit1: TRichEdit;
    procedure NodeWidthTrackBarChange(Sender: TObject);
    procedure NodeHeightTrackBarChange(Sender: TObject);
    procedure VertSpacingTrackBarChange(Sender: TObject);
    procedure HorzSpacingTrackBarChange(Sender: TObject);
    procedure CustomDrawingCheckBoxClick(Sender: TObject);
    procedure ShowButtonsCheckBoxClick(Sender: TObject);
    procedure ShowLinesCheckBoxClick(Sender: TObject);
    procedure TreeViewDrawNode(Sender: TObject; node: TRBTreeNode;
      NodeRect: TRect);
    procedure ButtonSizeTrackBarChange(Sender: TObject);
    procedure NodeColorComboBoxChange(Sender: TObject);
    procedure NodePenColorComboBoxChange(Sender: TObject);
    procedure TreeColorComboBoxChange(Sender: TObject);
    procedure LineColorComboBoxChange(Sender: TObject);
    procedure SetTreeFontButtonClick(Sender: TObject);
    procedure ShowRootCheckBoxClick(Sender: TObject);
    procedure NodeStyleRadioGroupClick(Sender: TObject);
    procedure ImageSideRadioGroupClick(Sender: TObject);
    procedure LineStyleRadioGroupClick(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

var
  MainDemo: TMainDemo;

implementation

{$R *.DFM}

procedure TMainDemo.NodeWidthTrackBarChange(Sender: TObject);
begin
  TreeView.NodeWidth := NodeWidthTrackBar.Position;
end;

procedure TMainDemo.NodeHeightTrackBarChange(Sender: TObject);
begin
  TreeView.NodeHeight := NodeHeightTrackBar.Position;
end;

procedure TMainDemo.VertSpacingTrackBarChange(Sender: TObject);
begin
  TreeView.VertSpacing := VertSpacingTrackBar.Position;
end;

procedure TMainDemo.HorzSpacingTrackBarChange(Sender: TObject);
begin
  TreeView.HorzSpacing := HorzSpacingTrackBar.Position;
end;

procedure TMainDemo.CustomDrawingCheckBoxClick(Sender: TObject);
begin
  TreeView.DefaultDrawing := CustomDrawingCheckBox.Checked;
end;

procedure TMainDemo.ShowButtonsCheckBoxClick(Sender: TObject);
begin
  TreeView.ShowButtons := ShowButtonsCheckBox.Checked;
end;

procedure TMainDemo.ShowLinesCheckBoxClick(Sender: TObject);
begin
  TreeView.ShowLines := ShowLinesCheckBox.Checked;
end;

procedure TMainDemo.TreeViewDrawNode(Sender: TObject; node: TRBTreeNode;
  NodeRect: TRect);
var
  a : array[0..3] of TPoint;
begin
  with TreeView.Canvas do
  begin
    Pen.Color := clBlack;
    Pen.Width := 0;
    Pen.Style := psSolid;
    Brush.Style := bsSolid;
    case Node.Level of
    0:
      begin
        Brush.Color := clYellow;
        if Node.Selected then Brush.Color := clRed;
        Ellipse ( NodeRect.Left , NodeRect.Top , NodeRect.Right , NodeRect.Bottom );
      end;
    1:
      begin
        Brush.Color := clGreen;
        if Node.Selected then Brush.Color := clRed;
        Rectangle ( NodeRect.Left , NodeRect.Top , NodeRect.Right , NodeRect.Bottom );
      end;
    2:
      begin
        Brush.Color := clOlive;
        if Node.Selected then Brush.Color := clRed;        
        a[0] := Point ( (NodeRect.Left + NodeRect.Right) div 2 , NodeRect.Top );
        a[1] := Point ( NodeRect.Right , (NodeRect.Top + NodeRect.Bottom) div 2 );
        a[2] := Point ( (NodeRect.Left + NodeRect.Right) div 2 , NodeRect.Bottom );
        a[3] := Point ( NodeRect.Left , (NodeRect.Top + NodeRect.Bottom) div 2 );
        Polygon ( a );
      end;
    end;

    DrawTextEx ( Handle , PChar ( Node.Text ) , Length( Node.Text ) , NodeRect ,
                 DT_CENTER or DT_END_ELLIPSIS or DT_SINGLELINE or
                 DT_VCENTER , nil );
  end;
end;

procedure TMainDemo.ButtonSizeTrackBarChange(Sender: TObject);
begin
  TreeView.ButtonSize := ButtonSizeTrackBar.Position;
end;

procedure TMainDemo.NodeColorComboBoxChange(Sender: TObject);
begin
  TreeView.NodeColor := NodeColorComboBox.ColorValue;
end;

procedure TMainDemo.NodePenColorComboBoxChange(Sender: TObject);
begin
  TreeView.NodePenColor := NodePenColorComboBox.ColorValue;
end;


procedure TMainDemo.TreeColorComboBoxChange(Sender: TObject);
begin
  TreeView.Color := TreeColorComboBox.ColorValue;
end;


procedure TMainDemo.LineColorComboBoxChange(Sender: TObject);
begin
  TreeView.LineColor := LineColorComboBox.ColorValue;
end;

procedure TMainDemo.SetTreeFontButtonClick(Sender: TObject);
begin
  if TreeFontDialog.Execute then TreeView.Font := TreeFontDialog.Font;
end;


procedure TMainDemo.ShowRootCheckBoxClick(Sender: TObject);
begin
  TreeView.ShowRoot := ShowRootCheckBox.Checked;
end;

procedure TMainDemo.NodeStyleRadioGroupClick(Sender: TObject);
begin
  if NodeStyleRadioGroup.ItemIndex = 0 then TreeView.NodeStyle := nsSimple
  else TreeView.NodeStyle := nsShadowed;
end;

procedure TMainDemo.ImageSideRadioGroupClick(Sender: TObject);
begin
  if ImageSideRadioGroup.ItemIndex = 0 then TreeView.NodeImageSide := nisLeft
  else TreeView.NodeImageSide := nisRight;
end;

procedure TMainDemo.LineStyleRadioGroupClick(Sender: TObject);
begin
  case LineStyleRadioGroup.ItemIndex of
  0: TreeView.LineStyle := psSolid;
  1: TreeView.LineStyle := psDash;
  2: TreeView.LineStyle := psDot;
  3: TreeView.LineStyle := psDashDot;
  4: TreeView.LineStyle := psDashDotDot;
  end;
end;




end.
